API Reference — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# API Reference

Here is the reference documentation to the eprllib API.

## eprllib

eprllib provides a set of methods to establish the computational loop of EnergyPlus within a Markov Decision Process (MDP), treating it as a multi-agent environment compatible with RLlib. The main goal is to offer a simple configuration of EnergyPlus as a standard environment for experimentation with Deep Reinforcement Learning.

Modules

`Env` | Environments
`Agents` | Agents
`ActionFunctions` | Action Functions
`ObservationFunctions` | Observation Functions
`RewardFunctions` | Reward Functions
`EpisodeFunctions` | Episode Functions
`Utils` | Utilities
`PostProcess` | Post Process Functions